# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Classes

### Public Classes

* [`netdata`](#netdata): Installs and configures netdata on your system.

### Private Classes

* `netdata::config`: Private class for managing netdata configuration.
* `netdata::install`: Private class for installing netdata packages.
* `netdata::params`: Private class providing default values for netdata parameters.
* `netdata::repo`: Private class for managing the netdata package repository.
* `netdata::service`: Private class for managing the netdata service.

## Classes

### netdata

Installs and configures netdata on your system.

When this class is declared with the default options, Puppet:

- Installs the appropriate netdata software package for your operating system.
- Places the required configuration files in a directory, with the default location determined by your operating system.
- Starts and the enables the netdata service.

#### Examples

##### Basic usage

```puppet
class { 'netdata': }
```

#### Parameters

The following parameters are available in the `netdata` class.

##### `manage_yumrepo`

Data type: `boolean`

Whether the netdata package repository is managed (Red Hat OS family only).

Default value: $netdata::params::manage_yumrepo

##### `yumrepo`

Data type: `hash`

A hash of netdata package repository `yumrepo` resources to create (Red Hat OS family only).

Default value: $netdata::params::yumrepo

##### `manage_package`

Data type: `boolean`

Whether the netdata package is managed.

Default value: $netdata::params::manage_package

##### `package_name`

Data type: `string`

The name of the netdata package.

Default value: $netdata::params::package_name

##### `package_ensure`

Data type: `string`

What state the netdata package should be in.

Default value: $netdata::params::package_ensure

##### `manage_cfg_dir`

Data type: `boolean`

Whether the netdata configuration directory is managed.

Default value: $netdata::params::manage_cfg_dir

##### `cfg_dir`

Data type: `string`

The path to the netdata configuration directory.

Default value: $netdata::params::cfg_dir

##### `manage_main_cfg`

Data type: `boolean`

Whether the netdata main configuration file is managed.

Default value: $netdata::params::manage_main_cfg

##### `main_cfg_file`

Data type: `string`

The path to the netdata main configuration file.

Default value: $netdata::params::main_cfg_file

##### `main_cfg`

Data type: `hash`

A hash of netdata main configuration settings.

Default value: $netdata::params::main_cfg

##### `manage_apps_groups_cfg`

Data type: `boolean`

Whether the netdata apps.plugin process grouping configuration file is managed.

Default value: $netdata::params::manage_apps_groups_cfg

##### `apps_groups_cfg_file`

Data type: `string`

The path to the netdata apps.plugin process grouping configuration file.

Default value: $netdata::params::apps_groups_cfg_file

##### `apps_groups_cfg`

Data type: `hash`

A hash of netdata apps.plugin process grouping configuration settings.

Default value: $netdata::params::apps_groups_cfg

##### `manage_charts_d_cfg`

Data type: `boolean`

Whether the netdata charts.d.plugin configuration file is managed.

Default value: $netdata::params::manage_charts_d_cfg

##### `charts_d_cfg_file`

Data type: `string`

The path to the netdata charts.d.plugin configuration file.

Default value: $netdata::params::charts_d_cfg_file

##### `charts_d_cfg`

Data type: `hash`

A hash of netdata charts.d.plugin configuration settings.

Default value: $netdata::params::charts_d_cfg

##### `manage_fping_cfg`

Data type: `boolean`

Whether the netdata fping.plugin configuration file is managed.

Default value: $netdata::params::manage_fping_cfg

##### `fping_cfg_file`

Data type: `string`

The path to the netdata fping.plugin configuration file.

Default value: $netdata::params::fping_cfg_file

##### `fping_bin`

Data type: `string`

The fping binary to use for netdata fping.plugin. Use 'absent' to remove from configuration file.

Default value: $netdata::params::fping_bin

##### `fping_hosts`

Data type: `array`

Hosts to fping with netdata fping.plugin.

Default value: $netdata::params::fping_hosts

##### `fping_update_every`

Data type: `string`

The update frequency of the chart for netdata fping.plugin. Use 'absent' to remove from configuration file.

Default value: $netdata::params::fping_update_every

##### `fping_ping_every`

Data type: `string`

The time in milliseconds to ping the hosts with netdata fping.plugin. Use 'absent' to remove from configuration file.

Default value: $netdata::params::fping_ping_every

##### `fping_opts`

Data type: `string`

Other fping options for netdata fping.plugin. Use 'absent' to remove from configuration file.

Default value: $netdata::params::fping_opts

##### `manage_node_d_cfg`

Data type: `boolean`

Whether the netdata node.d.plugin configuration file is managed.

Default value: $netdata::params::manage_node_d_cfg

##### `node_d_cfg_file`

Data type: `string`

The path to the netdata node.d.plugin configuration file.

Default value: $netdata::params::node_d_cfg_file

##### `node_d_cfg`

Data type: `hash`

A hash of netdata node.d.plugin configuration settings.

Default value: $netdata::params::node_d_cfg

##### `manage_python_d_cfg`

Data type: `boolean`

Whether the netdata python.d.plugin configuration file is managed.

Default value: $netdata::params::manage_python_d_cfg

##### `python_d_cfg_file`

Data type: `string`

The path to the netdata python.d.plugin configuration file.

Default value: $netdata::params::python_d_cfg_file

##### `python_d_cfg`

Data type: `hash`

A hash of netdata python.d.plugin configuration settings.

Default value: $netdata::params::python_d_cfg

##### `manage_stream_cfg`

Data type: `boolean`

Whether the netdata stream configuration file is managed.

Default value: $netdata::params::manage_stream_cfg

##### `stream_cfg_file`

Data type: `string`

The path to the netdata stream configuration file.

Default value: $netdata::params::stream_cfg_file

##### `stream_enabled`

Data type: `boolean`

Whether this node should send metrics.

Default value: $netdata::params::stream_enabled

##### `stream_destination`

Data type: `string`

Destination for stream (`[PROTOCOL:]HOST[%INTERFACE][:PORT]`).

Default value: $netdata::params::stream_destination

##### `stream_api_key`

Data type: `string`

The API_KEY to use (as the sender).

Default value: $netdata::params::stream_api_key

##### `stream_timeout`

Data type: `integer`

The timeout to connect and send metrics.

Default value: $netdata::params::stream_timeout

##### `stream_default_port`

Data type: `integer`

Default port if not specified by `stream_destination`.

Default value: $netdata::params::stream_default_port

##### `stream_buffer_size_bytes`

Data type: `integer`

The buffer to use for sending metrics.

Default value: $netdata::params::stream_buffer_size_bytes

##### `stream_reconnect_delay`

Data type: `integer`

Number of seconds to wait before after connection failure or disconnection.

Default value: $netdata::params::stream_reconnect_delay

##### `stream_initial_clock_resync`

Data type: `integer`

Number of clock sync iteration attempts between sending and receiving netdata hosts when starting.

Default value: $netdata::params::stream_initial_clock_resync

##### `stream_options_per_id`

Data type: `hash`

A hash of configuration settings to be applied per API_KEY or per MACHINE_GUID for netdata sending hosts on netdata receiving host.

Default value: $netdata::params::stream_options_per_id

##### `manage_service`

Data type: `boolean`

Whether the netdata service is managed.

Default value: $netdata::params::manage_service

##### `service_name`

Data type: `string`

The name of the netdata service to run.

Default value: $netdata::params::service_name

##### `ensure_service`

Data type: `string`

Whether the netdata service should be running.

Default value: $netdata::params::ensure_service

##### `enable_service`

Data type: `boolean`

Whether the netdata service should be enabled to start at boot.

Default value: $netdata::params::enable_service

